@@ -1,4 +1,4 @@
-# These are the files on which we do substitutions...
+# These are the files on which we do substitutionization.
 use vars qw($subst_files);
 $subst_files = {
 		'wrapper.IN' => 'wrapper',
@@ -6,6 +6,7 @@ $subst_files = {
 		'test.IN' => 'test.env',
 		'profile.IN' => 'etc/login/dot.profile',
 		'login.IN' => 'etc/login/dot.login',
+		'envy.IN' => 'envy.pl',
 	    };
 
 1;
